/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright (C) 2008 Luigi Ziviani <ziviani_luigi@yahoo.it> All Rights Reserved.*
*********************************************************************************
* Id: propertiesdialog.cpp,   v 1.0                    2008/01/01               *
*********************************************************************************
* This program is free software; you can redistribute it and/or modify          *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* This program is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/
#include "xincs.h"
#include "fx.h"
#include "PropertiesDialog.h"
#include "fxmoviemanager.h"
#include "icons.h"
#include <stdio.h>
#include <stdlib.h>


FXIMPLEMENT(PropertiesDialog,FXDialogBox,NULL,0)


// Create properties dialog
PropertiesDialog::PropertiesDialog(FXWindow *own):FXDialogBox(own,"Movie Properties",DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,0,0,660,440, 4,4,4,4, 4,4){

  accepticon=new FXGIFIcon(getApp(),m_accept);

  setTitle(tr("Movie Properties"));

  // Buttons
  FXHorizontalFrame *closebox=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH);
  new FXButton(closebox,tr("&CLOSE"),accepticon,this,FXDialogBox::ID_ACCEPT,ICON_BEFORE_TEXT|LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0, 20,20,5,5);

  // Separator
  new FXHorizontalSeparator(this,SEPARATOR_GROOVE|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);

  // Information
  FXVerticalFrame *generalFrame=new FXVerticalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_RAISED|FRAME_THICK);

  FXGroupBox *namegroup=new FXGroupBox(generalFrame,tr("Description"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
  filename=new FXLabel(namegroup,FXString::null,NULL,LAYOUT_CENTER_Y|LAYOUT_SIDE_LEFT|ICON_BEFORE_TEXT|LAYOUT_FIX_HEIGHT,0,0,0,40);
  filename->setTarget(own);
  filename->setSelector(FXMovieManager::ID_FILE_DESC);


  FXGroupBox *attrgroup=new FXGroupBox(generalFrame,tr("Attributes"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
  FXMatrix *attrmatrix=new FXMatrix(attrgroup,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);
  new FXLabel(attrmatrix,tr("Type:"),NULL,LAYOUT_RIGHT);
  filetype=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  filetype->setTarget(own);
  filetype->setSelector(FXMovieManager::ID_FILE_TYPE);
  new FXLabel(attrmatrix,tr("Location:"),NULL,LAYOUT_RIGHT);
  directory=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  directory->setTarget(own);
  directory->setSelector(FXMovieManager::ID_FILE_LOCATION);
  new FXLabel(attrmatrix,tr("Size:"),NULL,LAYOUT_RIGHT);
  filesize=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  filesize->setTarget(own);
  filesize->setSelector(FXMovieManager::ID_FILE_SIZE);
  new FXLabel(attrmatrix,tr("Video:"),NULL,LAYOUT_RIGHT);
  videoaspect=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  videoaspect->setTarget(own);
  videoaspect->setSelector(FXMovieManager::ID_VIDEO_ASPECT);
  new FXLabel(attrmatrix,tr("Audio:"),NULL,LAYOUT_RIGHT);
  audioformat=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  audioformat->setTarget(own);
  audioformat->setSelector(FXMovieManager::ID_AUDIO_FORMAT);


  FXGroupBox *timegroup=new FXGroupBox(generalFrame,tr("File Times"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
  FXMatrix *timematrix=new FXMatrix(timegroup,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);
  new FXLabel(timematrix,tr("Created:"),NULL,LAYOUT_RIGHT);
  createtime=new FXLabel(timematrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  createtime->setTarget(own);
  createtime->setSelector(FXMovieManager::ID_FILE_CREATED);
  new FXLabel(timematrix,tr("Modified:"),NULL,LAYOUT_RIGHT);
  modifytime=new FXLabel(timematrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  modifytime->setTarget(own);
  modifytime->setSelector(FXMovieManager::ID_FILE_MODIFIED);
  new FXLabel(timematrix,tr("Accessed:"),NULL,LAYOUT_RIGHT);
  accesstime=new FXLabel(timematrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  accesstime->setTarget(own);
  accesstime->setSelector(FXMovieManager::ID_FILE_ACCESSED);
  }

// Destroy
PropertiesDialog::~PropertiesDialog(){
  }
