/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright (C) 2008 Luigi Ziviani <ziviani_luigi@yahoo.it> All Rights Reserved.*
*********************************************************************************
* Id: fxmoviemanager.cpp,   v 1.4                    2008/01/01                 *
*********************************************************************************
* This program is free software; you can redistribute it and/or modify          *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* This program is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#include <fx.h>
#include "fxmoviemanager.h"
#include "icons.h"
#include "OperationsDialog.h"
#include "PropertiesDialog.h"

static const FXchar sourcefiles[]=
	"All Files (*)"
	"\nmpeg (*.mpeg,*.MPEG,*.mpg,*.MPG,*.mp4,*.MP4)"
	"\navi (*.avi,*.AVI)"
	"\nwindows media (*.wmv,*.WMV,*.wma,*.WMA,*.asf,*.ASF)"
	"\nquicktime (*.mov,*.MOV,*.qt,*.QT,*.mod,*.MOD)"
	"\nmobile (*.3gp,*.3GP,*.3gp2,*.3GP2)"
	"\nreal media (*.rm,*.RM)";


FXDEFMAP(FXMovieManager) FXMovieManagerMap[] = {
	//________Message_Type_____________________________ID______________________Message_Handler__________
	// buttons
	FXMAPFUNC(SEL_COMMAND,      		FXMovieManager::ID_ABOUT,      	FXMovieManager::onCmdAbout),
	FXMAPFUNC(SEL_COMMAND,      		FXMovieManager::ID_QUIT,       	FXMovieManager::onCmdQuit),
	FXMAPFUNC(SEL_SIGNAL,        		FXMovieManager::ID_QUIT,       	FXMovieManager::onCmdQuit),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_FILE,       	FXMovieManager::onCmdFile),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_VIDEO,      	FXMovieManager::onCmdVideo),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_AUDIO,	FXMovieManager::onCmdAudio),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_AUDIO,	FXMovieManager::onUpdSelectedList),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_PLAY,       	FXMovieManager::onCmdPlay),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_PLAY,	FXMovieManager::onUpdSelectedList),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_PAUSE,      	FXMovieManager::onCmdPause),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_PAUSE,	FXMovieManager::onUpdSelectedList),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_STOP,       	FXMovieManager::onCmdStop),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_STOP,	FXMovieManager::onUpdSelectedList),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_DROP,       	FXMovieManager::onCmdDrop),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_DROP,	FXMovieManager::onUpdSelectedList),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_LOOP,       	FXMovieManager::onCmdLoop),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_FULL,       	FXMovieManager::onCmdFull),
 	// play list 
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_PUTBACK,    	FXMovieManager::onCmdPutBack),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_MOVEUP,     	FXMovieManager::onCmdMoveUp),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_MOVEDOWN,   	FXMovieManager::onCmdMoveDown),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_APPEND,     	FXMovieManager::onCmdAppend),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_INSERT,     	FXMovieManager::onCmdInsert),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_REPLACE,    	FXMovieManager::onCmdReplace),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_SELECTALL,  	FXMovieManager::onCmdSelectAll),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_DELETE,     	FXMovieManager::onCmdDelete),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_CLEAR,      	FXMovieManager::onCmdClear),
	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,	FXMovieManager::ID_LIST,   	FXMovieManager::onListRightMouse),
	// directory list
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_DIRECTORYLIST,FXMovieManager::onCmdDirectory),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_UPDIRECTORY,	FXMovieManager::onCmdUpDirectory),
	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,	FXMovieManager::ID_DIRECTORYLIST,FXMovieManager::onDirListPopup),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_NEWDIR,	FXMovieManager::onCmdNewDir),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_NEWDIR,	FXMovieManager::onUpdNewDir),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_DIRDELETE,	FXMovieManager::onCmdDirDelete),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_DIRDELETE,	FXMovieManager::onUpdNewDir),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_DIRRENAME,	FXMovieManager::onCmdDirRename),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_DIRRENAME,	FXMovieManager::onUpdNewDir),
	// file list
	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,	FXMovieManager::ID_FILELIST,	FXMovieManager::onFileListPopup),
	FXMAPFUNC(SEL_DOUBLECLICKED, 		FXMovieManager::ID_FILELIST,   	FXMovieManager::onCmdFileList),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILECOPY,	FXMovieManager::onCmdFileCopy),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILECOPY,	FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEMOVE,	FXMovieManager::onCmdFileMove),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEMOVE,	FXMovieManager::onUpdSelectedFile),
   	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILERENAME,	FXMovieManager::onCmdFileRename),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILERENAME,	FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEDELETE,	FXMovieManager::onCmdFileDelete),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEDELETE,	FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEPLAY,	FXMovieManager::onCmdFilePlay),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEPLAY,	FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEPAUSE,	FXMovieManager::onCmdFilePause),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEPAUSE,	FXMovieManager::onUpdSelectedFile),
	FXMAPFUNC(SEL_COMMAND,       		FXMovieManager::ID_FILESTOP,   	FXMovieManager::onCmdFileStop),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILESTOP,	FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEPREVIEW,	FXMovieManager::onCmdFilePreview),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEPREVIEW, FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FORCEFILEPREVIEW,FXMovieManager::onCmdForceFilePreview),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FORCEFILEPREVIEW,FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_INCFILEPREVIEW,FXMovieManager::onCmdIncFilePreview),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_INCFILEPREVIEW,FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_DECFILEPREVIEW,FXMovieManager::onCmdDecFilePreview),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_DECFILEPREVIEW,FXMovieManager::onUpdSelectedFile),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_CLEARPREVIEW,FXMovieManager::onCmdClearPreview),
	// properties 
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_PROPERTIES,	FXMovieManager::onCmdProperties),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_CREATED,FXMovieManager::onUpdCreateTime),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_MODIFIED,FXMovieManager::onUpdModifyTime),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_ACCESSED,FXMovieManager::onUpdAccessTime),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_TYPE,	FXMovieManager::onUpdFileType),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_LOCATION,FXMovieManager::onUpdFileLocation),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_SIZE,	FXMovieManager::onUpdFileSize),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_DESC,	FXMovieManager::onUpdFileDesc),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_VIDEO_ASPECT,FXMovieManager::onUpdMovieAspect),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_AUDIO_FORMAT,FXMovieManager::onUpdAudioFormat),
};

FXIMPLEMENT(FXMovieManager, FXMainWindow, FXMovieManagerMap, ARRAYNUMBER(FXMovieManagerMap))

FXMovieManager::FXMovieManager(FXApp *a)
	:FXMainWindow(a, "FileManager, PlayList and MPlayer GUI", NULL, NULL, DECOR_TITLE|DECOR_MINIMIZE|DECOR_MAXIMIZE|DECOR_CLOSE|DECOR_BORDER|DECOR_SHRINKABLE|DECOR_STRETCHABLE|DECOR_MENU, 0, 0, 600, 40) {


	// button icons
	quiticon=new FXGIFIcon(getApp(),b_quit);
	fileicon=new FXGIFIcon(getApp(),b_file);
	listicon=new FXGIFIcon(getApp(),b_list);
	videoicon=new FXGIFIcon(getApp(),b_video);
	audioicon=new FXGIFIcon(getApp(),b_audio);
	playicon=new FXGIFIcon(getApp(),b_play);
	pauseicon=new FXGIFIcon(getApp(),b_pause);
	stopicon=new FXGIFIcon(getApp(),b_stop);
	conficon=new FXGIFIcon(getApp(),b_conf);
	upicon=new FXGIFIcon(getApp(),b_up);
	downicon=new FXGIFIcon(getApp(),b_down);
	trashicon=new FXGIFIcon(getApp(),b_trash);
	allicon=new FXGIFIcon(getApp(),b_all);
	hiddenicon=new FXGIFIcon(getApp(),b_hide);
	incvidicon=new FXGIFIcon(getApp(),b_incvid);
	decvidicon=new FXGIFIcon(getApp(),b_decvid);
	delvidicon=new FXGIFIcon(getApp(),b_delvid);
	previdicon=new FXGIFIcon(getApp(),b_previd);
	frevidicon=new FXGIFIcon(getApp(),b_frevid);


	// popup list menu icons
        m_upicon=new FXGIFIcon(getApp(),m_up);
        m_downicon=new FXGIFIcon(getApp(),m_down);
        m_appendicon=new FXGIFIcon(getApp(),m_append);
  	m_cancelicon=new FXGIFIcon(getApp(),m_cancel);
  	m_accepticon=new FXGIFIcon(getApp(),m_accept);
	// popup file menu icons
	m_propicon=new FXGIFIcon(getApp(),m_properties);
        m_copyicon=new FXGIFIcon(getApp(),m_copy);
        m_moveicon=new FXGIFIcon(getApp(),m_move);
        m_renameicon=new FXGIFIcon(getApp(),m_rename);
        m_deleteicon=new FXGIFIcon(getApp(),m_delete);
        m_refreshicon=new FXGIFIcon(getApp(),m_refresh);
        m_renamediricon=new FXGIFIcon(getApp(),m_renamedir);
        m_showhiddenicon=new FXGIFIcon(getApp(),m_showhidden);

	// Make the fonts
	boldfont=new FXFont(getApp(),"Sans,100,bold,regular");

	// menubar
	menubar = new FXMenuBar(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	quitbutton = new FXButton(menubar,"Quit\tQuit the application",quiticon,this,ID_QUIT,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	quitbutton->setTextColor(FXRGB(0,0,0));
	quitbutton->setFont(boldfont);

	openbutton = new FXButton(menubar,"Open\tAdd files to the playlist",fileicon,this,ID_FILE,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	openbutton->setTextColor(FXRGB(0,0,0));
	openbutton->setFont(boldfont);

	audiobutton = new FXToggleButton(menubar,"Mute\tMPlayer must be running","Audio\tMPlayer must be running",audioicon,audioicon,this,ID_AUDIO,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	audiobutton->setTextColor(FXRGB(250,0,0));
	audiobutton->setFont(boldfont);

	dropbutton = new FXToggleButton(menubar,"Drop\tMPlayer must be running","Nodrop\tMPlayer must be running",conficon,conficon,this,ID_DROP,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	dropbutton->setTextColor(FXRGB(250,0,0));
	dropbutton->setFont(boldfont);

	stopbutton = new FXButton(menubar,"Stop\tStop Player",stopicon,this,ID_STOP,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	stopbutton->setTextColor(FXRGB(0,0,0));
	stopbutton->setFont(boldfont);

	pausebutton = new FXButton(menubar,"Pause\tMPlayer must be running",pauseicon,this,ID_PAUSE,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	pausebutton->setTextColor(FXRGB(250,0,0));
	pausebutton->setFont(boldfont);

	playbutton = new FXButton(menubar,"Play\tPlay the selected movies",playicon,this,ID_PLAY,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	playbutton->setTextColor(FXRGB(0,0,0));
	playbutton->setFont(boldfont);

	loopbutton = new FXToggleButton(menubar,"Loop\tPlay in loop","Once\tPlay once",conficon,conficon,this,ID_LOOP,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	loopbutton->setTextColor(FXRGB(0,0,0));
	loopbutton->setFont(boldfont);

	zoombutton = new FXToggleButton(menubar,"Zoom\tFull screen size","1:1\tReal video size",videoicon,videoicon,this,ID_FULL,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	zoombutton->setTextColor(FXRGB(0,0,0));
	zoombutton->setFont(boldfont);


	new FXLabel(menubar,"V:",NULL);
	combobox = new FXComboBox(menubar,5,this,ID_VIDEO,COMBOBOX_INSERT_LAST|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP);
	combobox->setNumVisible(9);
	combobox->appendItem("X11");
	combobox->appendItem("XV");
	combobox->appendItem("SDL");
	combobox->appendItem("VESA");
	combobox->appendItem("DGA");
	combobox->appendItem("XVID");
	combobox->appendItem("FBDV");
	combobox->appendItem("JPEG");
	combobox->appendItem("PNG");
	combobox->appendItem("NULL");


	new FXLabel(menubar,"I:",NULL);
	seekposition=new FXTextField(menubar,5,NULL,0,FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	seekposition->setText("00:00:00");

	new FXLabel(menubar,"L:",NULL);
	endposition=new FXTextField(menubar,5,NULL,0,FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	endposition->setText("01:00:00");


	// Splitter
	splitter1=new FXSplitter(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_VERTICAL|SPLITTER_REVERSED);

	// Make simplelist
	listframe=new FXHorizontalFrame(splitter1,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
  	simplelist = new FXList(listframe,this,ID_LIST,LIST_EXTENDEDSELECT|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL);
	simplelist->setBackColor(FXRGB(0,0,0) );
	simplelist->setTextColor(FXRGB(200,200,200) );
	simplelist->setSelBackColor(FXRGB(150,150,150) );
	simplelist->setSelTextColor(FXRGB(0,0,0) );

	new FXButton(menubar,"About\tAbout FxMovieManager",listicon,this,ID_ABOUT,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	// new FXButton(menubar,"FileList",listicon,listframe,FXWindow::ID_TOGGLESHOWN,BUTTON_TOOLBAR|FRAME_RAISED|ICON_AFTER_TEXT);
	hidebutton = new FXToggleButton(menubar,"Hide\tHide play list","Show\tShow play list",listicon,listicon,this,ID_PUTBACK,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	hidebutton->setTextColor(FXRGB(0,0,0));
	hidebutton->setFont(boldfont);

	listbuttonframe=new FXVerticalFrame(listframe,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
	new FXButton(listbuttonframe,"\tMove up the movie",upicon,this,FXMovieManager::ID_MOVEUP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(listbuttonframe,"\tMove down the movie",downicon,this,FXMovieManager::ID_MOVEDOWN,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(listbuttonframe,"\tSelect all movies",allicon,this,FXMovieManager::ID_SELECTALL,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(listbuttonframe,"\tClear the playlist",trashicon,this,FXMovieManager::ID_CLEAR,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);

	// Right mouse popup
	popupmenu = new FXMenuPane(this);
	playlistlabel = new FXLabel(popupmenu,"Play List");
	playlistlabel->setTextColor(FXRGB(150,0,0));
	new FXMenuCommand(popupmenu,"Move Up",m_upicon,this,FXMovieManager::ID_MOVEUP);
	new FXMenuCommand(popupmenu,"Move Down",m_downicon,this,FXMovieManager::ID_MOVEDOWN);
	new FXMenuSeparator(popupmenu);
	new FXMenuCommand(popupmenu,"Select All",m_accepticon,this,FXMovieManager::ID_SELECTALL);
	new FXMenuCommand(popupmenu,"Cancel All",m_cancelicon,this,FXMovieManager::ID_CLEAR);
	new FXMenuSeparator(popupmenu);
	new FXMenuCommand(popupmenu,"Append Items",m_appendicon,this,FXMovieManager::ID_APPEND);
//	new FXMenuCommand(popupmenu,"Insert",NULL,this,FXMovieManager::ID_INSERT);
//	new FXMenuCommand(popupmenu,"Replace",NULL,this,FXMovieManager::ID_REPLACE);
	new FXMenuCommand(popupmenu,"Cancel Item",m_cancelicon,this,FXMovieManager::ID_DELETE);


	// Make file associations object; shared between FXFileList and FXDirList
	associations=new FXFileDict(getApp());

	// file box
  	splitter2=new FXSplitter(splitter1,LAYOUT_SIDE_TOP|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_HORIZONTAL);
  	dirframe=new FXVerticalFrame(splitter2,LAYOUT_FIX_WIDTH|LAYOUT_FILL_Y|FRAME_THICK|FRAME_SUNKEN, 0,0,180,0, 0,0,0,0,0,0);
  	filebuttonframe=new FXHorizontalFrame(splitter2,LAYOUT_FILL_X|LAYOUT_FILL_Y, 0,0,0,0, 0,0,0,0,0,0);
  	fileframe=new FXVerticalFrame(filebuttonframe,LAYOUT_FILL_X|LAYOUT_FILL_Y, 0,0,0,0, 0,0,0,0,0,0);

  	// Folder List
  	dirlist=new FXDirList(dirframe,this,ID_DIRECTORYLIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_RIGHT|TREELIST_SHOWS_LINES|TREELIST_SHOWS_BOXES|TREELIST_BROWSESELECT|DIRLIST_NO_OWN_ASSOC);
  	dirlist->setAssociations(associations);
  	dirlist->dropEnable();
	dirlist->setBackColor(FXRGB(0,0,0) );
	dirlist->setTextColor(FXRGB(200,200,200) );
	dirlist->setSelBackColor(FXRGB(150,150,150) );
	dirlist->setSelTextColor(FXRGB(0,0,0) );

	// File list
	filelist=new FXFileList(fileframe,this,ID_FILELIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_BIG_ICONS|ICONLIST_AUTOSIZE|FILELIST_NO_OWN_ASSOC);
	filelist->setAssociations(associations);
  	filelist->dropEnable();
	filelist->setBackColor(FXRGB(0,0,0) );
	filelist->setTextColor(FXRGB(200,200,200) );
	filelist->setSelBackColor(FXRGB(150,150,150) );
	filelist->setSelTextColor(FXRGB(0,0,0) );


  	// Properties panel
  	properties=new PropertiesDialog(this);


	// to be filled with ..
	hbuttonframe=new FXHorizontalFrame(dirframe,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0, 0,0,0,0, 0,0);


	vbuttonframe=new FXVerticalFrame(filebuttonframe,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
	new FXButton(vbuttonframe,"\tMove one step up",upicon,this,ID_UPDIRECTORY,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
  	new FXToggleButton(vbuttonframe,"Show\tToggle Hidden Directories","Hide\tToggle Hidden Directories",hiddenicon,hiddenicon,filelist,FXFileList::ID_TOGGLE_HIDDEN,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
        new FXButton(vbuttonframe,"\tSelect All movies",allicon,filelist,FXFileList::ID_SELECT_ALL,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe,"\tThumbnail of selected movies",previdicon,this,ID_FILEPREVIEW,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	freshbutton = new FXButton(vbuttonframe,"\tRecreate Movie Thumbnails",frevidicon,this,ID_FORCEFILEPREVIEW,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	freshbutton->setTextColor(FXRGB(250,0,0));
	clearbutton = new FXButton(vbuttonframe,"\tTo delete hdden directories show them before",delvidicon,this,ID_CLEARPREVIEW,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	clearbutton->setTextColor(FXRGB(0,250,0));
	new FXButton(vbuttonframe,"\tIncrease size of thumbnail of movies",incvidicon,this,ID_INCFILEPREVIEW,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe,"\tDecrease size of thumbnail of movies",decvidicon,this,ID_DECFILEPREVIEW,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXMenuSeparator(vbuttonframe);
	new FXButton(vbuttonframe,"\tMPlayer must be running",stopicon,this,ID_FILESTOP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe,"\tMPlayer must be running",pauseicon,this,ID_FILEPAUSE,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe,"\tPlay selected movies",playicon,this,ID_FILEPLAY,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);


  	progressframe=new FXHorizontalFrame(fileframe,LAYOUT_FILL_X|FRAME_THICK|FRAME_SUNKEN, 0,0,0,0, 0,0,0,0,0,0);
	// Make a progress bar
        progressbar = new FXProgressBar(progressframe,NULL,0,PROGRESSBAR_HORIZONTAL|PROGRESSBAR_PERCENTAGE|PROGRESSBAR_NORMAL|LAYOUT_FILL_X);

  	// Make a tool tip
  	new FXToolTip(getApp(),0);

	// inithialize some parameters
	s_command = "mplayer -slave -idle -quiet -ontop -input file=/tmp/.fxmm/fifo ";
	isrunning = FALSE;
	imgw=80; imgh=64;

	system ("test -d /tmp/.fxmm || mkdir /tmp/.fxmm");
	system ("test -p /tmp/.fxmm/fifo || mkfifo /tmp/.fxmm/fifo");
}

FXMovieManager::~FXMovieManager() {
	delete quiticon;
	delete fileicon;
	delete listicon;
	delete videoicon;
	delete audioicon;
	delete playicon;
	delete pauseicon;
	delete conficon;
	delete upicon;
	delete downicon;
	delete trashicon;
	delete allicon;

	delete m_upicon;
	delete m_downicon;
	delete m_appendicon;
	delete m_accepticon;
	delete m_cancelicon;

	delete m_copyicon;
	delete m_moveicon;
	delete m_renameicon;
	delete m_deleteicon;
}


/*********************** ROUTINES ******************************/


// Load file
FXbool FXMovieManager::loadfile(const FXString& filename){
	FXString ext=FXPath::extension(filename);

	if(comparecase(ext,"mpeg")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"MPEG")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"mpg")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"MPG")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"mp4")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"MP4")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"avi")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"AVI")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"wmv")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"WMV")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"wma")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"WMA")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"asf")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"ASF")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"mov")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"MOV")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"mod")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"MOD")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"qt")==0){ 
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"QT")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"rm")==0){ 
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"RM")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"3gp")==0){ 
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"3GP")==0){
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"3gp2")==0){ 
		simplelist->appendItem(filename);
	}
	else if(comparecase(ext,"3GP2")==0){
		simplelist->appendItem(filename);
	}
	else {
		FXMessageBox::error(this,MBOX_OK,"Error Loading Movie","Unsupported type: %s",ext.text());
		return FALSE;
	}
  return TRUE;
}


// Load imagemovie on the list for preview
FXbool FXMovieManager::previewListMovie(const FXString& filename, FXint i){
    FXString imagename=filename;
    //printf("the current directory is: %s\n", filename.text());

    FXJPGIcon *tempicon=NULL;
    tempicon=new FXJPGIcon(getApp(),NULL,IMAGE_OPAQUE|IMAGE_KEEP);

    if (tempicon){

   	FXFileStream stream;
   	if (stream.open(imagename,FXStreamLoad)){
		getApp()->beginWaitCursor();
		tempicon->loadPixels(stream);
		stream.close();

		tempicon->scale(80,64,75); 
        	tempicon->create();

		simplelist->setItemIcon(i,tempicon);

		getApp()->endWaitCursor();

		return TRUE;
	}
    }
    return FALSE;
}

// get selected movies from file dialog
void FXMovieManager::getFiledialogSelection(){
	FXString rootname, imagename;

	currentdir = dirlist->getDirectory();

	FXString* files=FXFileDialog::getOpenFilenames(this,"Select the Movies to Append",currentdir,sourcefiles,1);
	if(files){
		for(int i=0; !files[i].empty(); i++){
			filename = files[i];
			loadfile(filename);

  			rootname=FXPath::name(FXPath::stripExtension(filename));
			imagename=FXPath::enquote(getDirectory())+"/."+rootname+"00000001/00000001.jpg";
    			//printf("the imagename is: %s\n", imagename.text());
        		FXint numitems = simplelist->getNumItems();
			//printf("the itemnumber is: %d\n", numitems-1);
  			previewListMovie(imagename, numitems-1);
		}
		// clean up files
		delete [] files;
	}
	selectAll();
	return;
}

// get selected movies from file list
void FXMovieManager::getFilelistSelection() {
  // load one file at a time
  FXint numitems = simplelist->getNumItems();

  FXString ffile,rootname,imagename;
  for(FXint i=0; i<filelist->getNumItems(); i++){
    	if(filelist->isItemSelected(i)){
        	ffile=filelist->getItemFilename(i);
        	if(ffile=="..") continue;

  		rootname=FXPath::stripExtension(ffile);
  		imagename=FXPath::enquote(getDirectory())+"/."+rootname+"00000001/00000001.jpg";
    		//printf("the imagename is: %s\n", imagename.text());
		previewListMovie(imagename, numitems-1);
		//printf("the numitems is: %d\n", numitems-1);
	}
  }
  return;	
}

// load configuration
FXbool FXMovieManager::readConfig() {

  // Get size and position
#ifdef FOX_17
  FXuint width=getApp()->reg().readUIntEntry("WINDOW","width",600);
  FXuint height=getApp()->reg().readUIntEntry("WINDOW","height",40);
#endif
#ifdef FOX_16
  FXuint width=getApp()->reg().readUnsignedEntry("WINDOW","width",600);
  FXuint height=getApp()->reg().readUnsignedEntry("WINDOW","height",40);
#endif 

  FXint xpos=getApp()->reg().readIntEntry("WINDOW","xpos",40);
  FXint ypos=getApp()->reg().readIntEntry("WINDOW","ypos",5);

  // Reposition window
  position(xpos,ypos,width,height);

  // Read menu options

  s_full=getApp()->reg().readStringEntry("MENU","s_full");
  s_loop=getApp()->reg().readStringEntry("MENU","s_loop");
  s_frame=getApp()->reg().readStringEntry("MENU","s_frame");
  s_audio=getApp()->reg().readStringEntry("MENU","s_audio");

  i_video=getApp()->reg().readIntEntry("MENU","s_video",i_video);

  s_listshow=getApp()->reg().readStringEntry("MENU","s_listshow");

  currentdir=getApp()->reg().readStringEntry("FileList","currentdir");

  splitter2->setSplit(0,getApp()->reg().readIntEntry("FileList","dirwidth",300));
  splitter1->setSplit(1,getApp()->reg().readIntEntry("FileList","dirheigth",300));

  // Read registry settings
  getApp()->reg().read();

  return TRUE;
}

// create application
void FXMovieManager::create() {

  readConfig();

  dirlist->setDirectory(currentdir);
  filelist->setDirectory(currentdir);

  if(s_listshow=="false"){ hidebutton->setState(TRUE); listshow=false; } 
  else if(s_listshow=="true"){ hidebutton->setState(FALSE); listshow=true;}

  if(s_full==""){ zoombutton->setState(FALSE); } 
  else if(s_full=="-zoom -x 640 -y 480 "){ zoombutton->setState(TRUE); }

  if(s_loop==""){ loopbutton->setState(FALSE); } 
  else if(s_loop=="-loop 0 "){ loopbutton->setState(TRUE); }

  if(s_audio==""){ audiobutton->setState(FALSE); } 
  else if(s_audio=="-nosound "){ audiobutton->setState(TRUE); }

  if(s_frame==""){ dropbutton->setState(FALSE); } 
  else if(s_frame=="-framedrop "){ dropbutton->setState(TRUE); }

  if(i_video>9) {i_video=0;}
  combobox->setCurrentItem(i_video);

  switch(i_video){
	case 0:
		s_video="-vo x11 -fixed-vo ";
		break;
	case 1:
		s_video="-vo xv -fixed-vo ";
		break;
	case 2:
		s_video="-vo sdl -fixed-vo ";
		break;
	case 3:
		s_video="-vo vesa -fixed-vo ";
		break;
	case 4:
		s_video="-vo dga -fixed-vo ";
		break;
	case 5:
		s_video="-vo xvidix -fixed-vo ";
		break;
	case 6:
		s_video="-vo fbdev -fixed-vo ";
		break;
	case 7:
		s_video="-vo jpeg ";
		break;
	case 8:
		s_video="-vo png ";
		break;
	case 9:
		s_video="-vo null ";
		break;
	}

  FXMainWindow::create();
  show(PLACEMENT_SCREEN);
}


/**************************BUTTON COMMANDS****************************/

// quit application
long FXMovieManager::onCmdQuit(FXObject *,FXSelector,void *) {
  FXTRACE((100,"Quit\n"));
  // Write new window size and position back to registry
#ifdef FOX_17
  getApp()->reg().writeUIntEntry("WINDOW","width",(FXuint)getWidth());
  getApp()->reg().writeUIntEntry("WINDOW","height",(FXuint)getHeight());
#endif
#ifdef FOX_16
  getApp()->reg().writeUnsignedEntry("WINDOW","width",(FXuint)getWidth());
  getApp()->reg().writeUnsignedEntry("WINDOW","height",(FXuint)getHeight());
#endif 
  getApp()->reg().writeIntEntry("WINDOW","xpos",getX());
  getApp()->reg().writeIntEntry("WINDOW","ypos",getY());

  i_video=combobox->getCurrentItem();

  // Write mencoder options
  getApp()->reg().writeIntEntry("MENU","s_video",i_video);

  getApp()->reg().writeStringEntry("MENU","s_full",s_full.text());
  getApp()->reg().writeStringEntry("MENU","s_loop",s_loop.text());
  getApp()->reg().writeStringEntry("MENU","s_frame",s_frame.text());
  getApp()->reg().writeStringEntry("MENU","s_audio",s_audio.text());

  if (listshow==true) {s_listshow="true";}
  else if (listshow==false) {s_listshow="false";}
  getApp()->reg().writeStringEntry("MENU","s_listshow",s_listshow.text());

  currentdir = dirlist->getDirectory();
  getApp()->reg().writeStringEntry("FileList","currentdir",currentdir.text());

  getApp()->reg().writeIntEntry("FileList","dirwidth",splitter2->getSplit(0));
  getApp()->reg().writeIntEntry("FileList","dirheigth",splitter1->getSplit(1));

  // Write registry settings
  getApp()->reg().write();

  system ("test -p /tmp/.fxmm/fifo && rm /tmp/.fxmm/fifo");
  system ("test -p /tmp/.fxmm/video.txt && rm /tmp/.fxmm/video.txt");
  system ("test -p /tmp/.fxmm/audio.txt && rm /tmp/.fxmm/audio.txt");

  // Quit
  getApp()->exit(0);
  return 1;
}

// select multiple files
long FXMovieManager::onCmdFile(FXObject *,FXSelector,void *) {
/*
	FXFileDialog opendialog(this,"Open a new Source Movie",SELECTFILE_MULTIPLE);
	opendialog.setDirectory(currentdir);
	if(opendialog.execute()){
		currentdir=opendialog.getDirectory();
		FXString *files=opendialog.getFilenames();

		for(int i=0; !files[i].empty(); i++){
			filename = files[i];
			loadfile(filename);
		}
		// clean up files
		delete [] files;
	}
*/
	// Remove all items from list
	simplelist->clearItems();
	getFiledialogSelection();
	return 1;
}

// playlist video output selection 
long FXMovieManager::onCmdVideo(FXObject *,FXSelector,void *) {
	FXint choice;
	choice = combobox->getCurrentItem();
	switch(choice){
	case 0:
		s_video="-vo x11 -fixed-vo ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output X11 Enabled\nVideo on Top Enabled");
		break;
	case 1:
		s_video="-vo xv -fixed-vo ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output xv Enabled\nVideo on Top Disabled");
		break;
	case 2:
		s_video="-vo sdl -fixed-vo ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output sdl Enabled\nVideo on Top Disabled");
		break;
	case 3:
		s_video="-vo vesa -fixed-vo ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output vesa Enabled");
		break;
	case 4:
		s_video="-vo dga -fixed-vo ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output dga Enabled");
		break;
	case 5:
		s_video="-vo xvidix -fixed-vo ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output xvidix Enabled");
		break;
	case 6:
		s_video="-vo fbdev -fixed-vo ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output fbdev Enabled");
		break;
	case 7:
		s_video="-vo jpeg ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Output >>> jpeg files enabled");
		break;
	case 8:
		s_video="-vo png ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Output >>> jpeg files enabled");
		break;
	case 9:
		s_video="-vo null ";
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output Disabled");
		break;
	}
	return 1;
}

// list play command
long FXMovieManager::onCmdPlay(FXObject *,FXSelector,void *) {

	system ("test -p /tmp/.fxmm/fifo && rm /tmp/.fxmm/fifo");
	system ("test -p /tmp/.fxmm/fifo || mkfifo /tmp/.fxmm/fifo");

	// Return the number of items in the list
	numberofitems = simplelist->getNumItems();
//	printf("The number of items was %d\n", numberofitems);
	if(numberofitems >= 0){
		// Return the text of all items
		for(int i=0; i<numberofitems; ++i){
		if(simplelist->isItemSelected(i)){
			s_list += simplelist->getItemText(i);
			s_list += " ";
			// simplelist->deselectItem(i);
			// simplelist->repaint();
			}
		}
	}

	//get the position where to start playing of the movie	
	s_initial = "-ss " + seekposition->getText() + " ";
	s_duration = "-endpos " + endposition->getText() + " ";
	s_play = s_command + s_video + s_audio + s_frame + s_full + s_loop + s_initial + s_duration + s_list +"&";
//	printf("The playstring was: %s\n", playstr.text());
	system(s_play.text());
	isrunning = TRUE;
	// clear liststr
	s_list = "";
	return 1;
}

// playlist pause command
long FXMovieManager::onCmdPause(FXObject *,FXSelector,void *) {
	if (isrunning==TRUE){
		FILE *f;
		f=fopen("/tmp/.fxmm/fifo", "w");
		fprintf(f, "%s", "pause\n");
		fclose(f);
	} else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
	}
	return 1;
}

// playlist stop command
long FXMovieManager::onCmdStop(FXObject *,FXSelector,void *) {
	if (isrunning==TRUE){
		FILE *f;
		f=fopen("/tmp/.fxmm/fifo", "w");
		fprintf(f, "%s", "quit 1\n");
		fclose(f);
		isrunning=FALSE;
	} else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
	}
	return 1;
}

// playlist audio command
long FXMovieManager::onCmdAudio(FXObject *,FXSelector,void *) {
	if(s_audio==""){
		FILE *f;
		f=fopen("/tmp/.fxmm/fifo", "w");
		fprintf(f, "%s", "mute 1\n");
		fclose(f);
		s_audio="-nosound ";
	} else if(s_audio=="-nosound "){
		FILE *f;
		f=fopen("/tmp/.fxmm/fifo", "w");
		fprintf(f, "%s", "mute 0\n");
		fclose(f);
		s_audio= "";
	}
	return 1;
}

// playlist frame drop command
long FXMovieManager::onCmdDrop(FXObject *,FXSelector,void *) {
	if(s_frame==""){
		FILE *f;
		f=fopen("/tmp/.fxmm/fifo", "w");
		fprintf(f, "%s", "frame_drop 1\n");
		fclose(f);
		s_frame = "-framedrop ";
	} else if(s_frame=="-framedrop "){
		FILE *f;
		f=fopen("/tmp/.fxmm/fifo", "w");
		fprintf(f, "%s", "frame_drop 0\n");
		fclose(f);
		s_frame = "";
	}
	return 1;
}

// playlist video zoom command
long FXMovieManager::onCmdFull(FXObject *,FXSelector,void *) {
	if(s_full==""){
		s_full = "-zoom -x 640 -y 480 ";
		zoombutton->setState(TRUE);
	} else if(s_full=="-zoom -x 640 -y 480 "){
		s_full = "";
		zoombutton->setState(FALSE);
	}
	return 1;
}

// playlist loop command
long FXMovieManager::onCmdLoop(FXObject *,FXSelector,void *) {
	if(s_loop==""){
		s_loop = "-loop 0 ";
		loopbutton->setState(TRUE);
	} else if(s_loop=="-loop 0 "){
		s_loop = "";
		loopbutton->setState(FALSE);
	}
	return 1;
}

// playlist-filemanager hide command
long FXMovieManager::onCmdPutBack(FXObject *,FXSelector,void *) {
	if (listshow==false) {
		FXMainWindow::setHeight(600);
		FXMainWindow::repaint();
        	FXMainWindow::show(PLACEMENT_SCREEN);
		listshow=true;
		hidebutton->setState(FALSE);
	} else if (listshow==true) {
		FXMainWindow::setHeight(40);
		FXMainWindow::repaint();
        	FXMainWindow::show(PLACEMENT_SCREEN);
		listshow=false;
		hidebutton->setState(TRUE);
	}
	return 1;
}

/**************************LIST COMMANDS****************************/

// Move Up Command
long FXMovieManager::onCmdMoveUp(FXObject*,FXSelector,void*){
	// Return current item, if any
	indexnumber = simplelist->getCurrentItem();
	if(indexnumber >= 0){
		FXint newindexnumber = indexnumber-1;
		if(newindexnumber>=0){
			// Move Down the current item
			simplelist->moveItem(newindexnumber,indexnumber);
		}
	}
	return 1;
}

// Move Down Command
long FXMovieManager::onCmdMoveDown(FXObject*,FXSelector,void*){
	// Return the number of items in the list
	numberofitems = simplelist->getNumItems();
	// Return current item, if any
	indexnumber = simplelist->getCurrentItem();
	if(indexnumber >= 0){
		FXint newindexnumber = indexnumber+1;
		if(newindexnumber<numberofitems){
			// Move Down the current item
			simplelist->moveItem(newindexnumber,indexnumber);
		}
	}
	return 1;
}


// Append command
long FXMovieManager::onCmdAppend(FXObject *,FXSelector,void *) {
	getFiledialogSelection();
	return 1;
}


// Insert Command ------------------TO DO
long FXMovieManager::onCmdInsert(FXObject*,FXSelector,void*){
	// Return current item, if any
	indexnumber = simplelist->getCurrentItem();
	if(indexnumber < 0){
		FXMessageBox::error(this,MBOX_OK,"The list may be empty","Error Inserting File");
		return 1;
	}

	FXFileDialog open(this,"Insert Movie");
	open.setFilename(filename);
	if(open.execute()){
		filename=open.getFilename();
		// Insert at the current item position
		simplelist->insertItem(indexnumber, filename);
	}
	return 1;
}


// Replace Command-----------------TO DO
long FXMovieManager::onCmdReplace(FXObject*,FXSelector,void*){
	// Return current item, if any
	indexnumber = simplelist->getCurrentItem();
	if(indexnumber < 0){
		FXMessageBox::error(this,MBOX_OK,"The list may be empty","Error Replacing File");
		return 1;
	}

	FXFileDialog open(this,"Replace Movie");
	open.setFilename(filename);
	if(open.execute()){
		filename=open.getFilename();
		// Replace the current item
		simplelist->setItemText(indexnumber, filename);
	}
	return 1;
}


// Select All Command
long FXMovieManager::onCmdSelectAll(FXObject*,FXSelector,void*){
	selectAll();
	return 1;
}


// Delete Command
long FXMovieManager::onCmdDelete(FXObject*,FXSelector,void*){
	// Return the number of items in the list
	numberofitems = simplelist->getNumItems();
	if(numberofitems >= 0){
		// Remove all selected items
		for(int i=(numberofitems-1); i>=0; --i){
		if(simplelist->isItemSelected(i)){
			//printf("The item index selected was %d\n", i);
			simplelist->removeItem(i);
			}
		}
	}
/*
	// Return current item, if any
	indexnumber = simplelist->getCurrentItem();
	if(indexnumber >=0){
	// Remove the current item
	simplelist->removeItem(indexnumber);
	}
*/
	return 1;
}


// Clear Command
long FXMovieManager::onCmdClear(FXObject*,FXSelector,void*){
	// Remove all items from list
	simplelist->clearItems();
	return 1;
}


// Released right button
long FXMovieManager::onListRightMouse(FXObject*,FXSelector,void* ptr){
  FXEvent* event=(FXEvent*)ptr;
  if(!event->moved){
    popupmenu->popup(NULL,event->root_x,event->root_y);
    getApp()->runModalWhileShown(popupmenu);
    }
  return 1;
}


// Enable sender when items have been selected
long FXMovieManager::onUpdSelectedList(FXObject* sender,FXSelector,void*){
  sender->handle(this,getNumListnames()?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
  return 1;
  }


// Select All Command
void FXMovieManager::selectAll(){
	// Return the number of items in the list
	numberofitems = simplelist->getNumItems();
	if(numberofitems >= 0){
		for (int i=0; i<numberofitems; ++i){
			simplelist->selectItem(i);
		}
	}
  }


// Get number of selected filenames, not including "." and ".."
FXint FXMovieManager::getNumListnames() const {
  register FXint listnum=0;
  register FXint e;
  if(simplelist->getNumItems()){
    for(e=0; e<simplelist->getNumItems(); e++){
      if(simplelist->isItemSelected(e)) listnum++;
      }
    }
  return listnum;
  }

/****************************DIRECTORY LIST**********************************/

// Create new directory
long FXMovieManager::onCmdNewDir(FXObject*,FXSelector,void*){
  FXDialogBox dialog(this,"Create New Directory",DECOR_TITLE|DECOR_BORDER);
  const FXchar suggestedname[]="DirectoryName";
  FXVerticalFrame* content=new FXVerticalFrame(&dialog,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,10,10,10,10,10,10);
  new FXLabel(content,"Create new directory in: "+filelist->getDirectory(),NULL,LAYOUT_FILL_X|JUSTIFY_LEFT);
  FXTextField *text=new FXTextField(content,40,&dialog,FXDialogBox::ID_ACCEPT,TEXTFIELD_ENTER_ONLY|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X);
  new FXHorizontalSeparator(content,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame* buttons=new FXHorizontalFrame(content,LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
  new FXButton(buttons,"&YES",m_accepticon,&dialog,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT);
  new FXButton(buttons,"&Cancel",m_cancelicon,&dialog,FXDialogBox::ID_CANCEL,ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
  dialog.create();

  text->setText(suggestedname);
  text->setFocus();
  text->setSelection(0,sizeof(suggestedname));

  if(dialog.execute()){
    FXString dirname=FXPath::absolute(filelist->getDirectory(),text->getText());
    if(FXStat::exists(dirname)){
      FXMessageBox::error(this,MBOX_OK,"Already Exists","File or directory %s already exists.\n",dirname.text());
      }
    else if(!FXDir::create(dirname)){
      FXMessageBox::error(this,MBOX_OK,"Cannot Create","Cannot create directory %s.\n",dirname.text());
      }
    else {
      currentdir=dirname;
      dirlist->setDirectory(currentdir);
      filelist->setDirectory(currentdir);
    }
  }
  return 1;
}

// Delete directory the directory list
long FXMovieManager::onCmdDirDelete(FXObject*,FXSelector,void*){
  FXuint answer=FXMessageBox::warning(this,MBOX_YES_NO,"Deleting Directory","Are you sure you want to delete this directory?");
  if(answer==MBOX_CLICKED_YES){

    FXString dropdir=dirlist->getDirectory();
    FXTRACE((100,"dropdir=%s\n",dropdir.text()));
        if(!FXDir::remove(dropdir)){
          if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Deleting Directory","Unable to delete directory: %s\nContinue with operation?",dropdir.text())){
            return 1;
            }
        }
	else {
	  currentdir=FXPath::absolute(dirlist->getDirectory());
  	  dirlist->setDirectory(currentdir);
  	  filelist->setDirectory(currentdir);
	}
    }
  return 1;
  }

// Rename directory in the directory list
long FXMovieManager::onCmdDirRename(FXObject*,FXSelector,void*){

  FXString dirname=dirlist->getDirectory();

  FXDialogBox dialog(this,"Rename Directory",DECOR_TITLE|DECOR_BORDER);
  FXVerticalFrame* content=new FXVerticalFrame(&dialog,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,10,10,10,10,10,10);
  new FXLabel(content,"Old Directory Name: "+dirname,NULL,LAYOUT_FILL_X|JUSTIFY_LEFT);
  FXTextField *text=new FXTextField(content,40,&dialog,FXDialogBox::ID_ACCEPT,TEXTFIELD_ENTER_ONLY|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X);
  new FXHorizontalSeparator(content,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame* buttons=new FXHorizontalFrame(content,LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
  new FXButton(buttons,"&YES",m_accepticon,&dialog,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT);
  new FXButton(buttons,"&Cancel",m_cancelicon,&dialog,FXDialogBox::ID_CANCEL,ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
  dialog.create();

  text->setText(dirname);
  text->setFocus();

  if(dialog.execute()){

      //FXString suggestedname=FXPath::absolute(dirlist->getDirectory(),text->getText());
      FXString suggestedname=FXPath::absolute(text->getText());

      if(!FXDir::rename(dirname,suggestedname)){
        FXMessageBox::error(this,MBOX_OK,"Cannot Rename","Cannot Rename directory %s.\n",dirname.text());
      }
      else{
	//currentdir=FXPath::absolute(dirlist->getDirectory(),text->getText());
	currentdir=FXPath::absolute(text->getText());
  	dirlist->setDirectory(currentdir);
  	filelist->setDirectory(currentdir);
      }	
   } 
   return 1;
  }

// Update create new directory
long FXMovieManager::onUpdNewDir(FXObject* sender,FXSelector,void*){
  FXString path=filelist->getDirectory();
  if(FXStat::isWritable(path))
    sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
  else
    sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
  return 1;
  }


// Change the directory from the FXDirList
long FXMovieManager::onCmdDirectory(FXObject*,FXSelector,void* ptr){
  FXTreeItem *item=(FXTreeItem*)ptr;
  FXString path=dirlist->getItemPathname(item);
  filelist->setDirectory(path);
  return 1;
  }


// Move up one directory
long FXMovieManager::onCmdUpDirectory(FXObject*,FXSelector,void*){
  FXString path=FXPath::upLevel(filelist->getDirectory());
  filelist->setDirectory(path);
  dirlist->setDirectory(path);
  return 1;
  }




// Popup menu for item in dir list
long FXMovieManager::onDirListPopup(FXObject*,FXSelector,void* ptr){
  FXEvent *event=(FXEvent*)ptr;
  if(event->moved) return 1;

  FXMenuPane pane(dirlist);

    FXLabel *dirlistlabel = new FXLabel(&pane,"Directory Item");
    dirlistlabel->setTextColor(FXRGB(150,0,0));

    new FXMenuCommand(&pane,"Show/Hide",m_showhiddenicon,dirlist,FXDirList::ID_TOGGLE_HIDDEN);
    new FXMenuCommand(&pane,"New Dir...",m_appendicon,this,ID_NEWDIR);
    new FXMenuCommand(&pane,"Rename Dir",m_renamediricon,this,ID_DIRRENAME);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,"Delete Dir",m_deleteicon,this,ID_DIRDELETE);

  pane.create();
  pane.popup(NULL,event->root_x,event->root_y);
  getApp()->runModalWhileShown(&pane);
  return 1;
  }


/****************************FILE LIST**********************************/

// Popup menu for item in file list
long FXMovieManager::onFileListPopup(FXObject*,FXSelector,void* ptr){
  FXEvent *event=(FXEvent*)ptr;
  if(event->moved) return 1;
  FXint index=filelist->getItemAt(event->win_x,event->win_y);
  FXMenuPane pane(filelist);

  // We clicked in the background
  if(index<0){
    FXLabel *filebacklabel = new FXLabel(&pane,"Backgroung");
    filebacklabel->setTextColor(FXRGB(150,0,0));

    new FXMenuCommand(&pane,"Refresh",m_refreshicon,filelist,FXFileList::ID_REFRESH);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,"New Dir...",m_appendicon,this,ID_NEWDIR);
    }

  // We clicked on an item file or directory
  else{
    FXLabel *filelistlabel = new FXLabel(&pane,"File Item");
    filelistlabel->setTextColor(FXRGB(150,0,0));

    new FXMenuCommand(&pane,"Properties",m_propicon,this,ID_PROPERTIES);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,"Rename...",m_renameicon,this,ID_FILERENAME);
    new FXMenuCommand(&pane,"Move...",m_moveicon,this,ID_FILEMOVE);
    new FXMenuCommand(&pane,"Copy...",m_copyicon,this,ID_FILECOPY);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,"Delete",m_deleteicon,this,ID_FILEDELETE);
    }
  pane.create();
  pane.popup(NULL,event->root_x,event->root_y);
  getApp()->runModalWhileShown(&pane);
  return 1;
  }

// Command from the tree list
long FXMovieManager::onCmdFileList(FXObject*,FXSelector,void* ptr){
  FXint index=(FXint)(FXival)ptr;
  if(0<=index){
    if(filelist->isItemDirectory(index)){
      filelist->setDirectory(filelist->getItemPathname(index));
      }
    else if(filelist->isItemFile(index)){
      filename=filelist->getItemPathname(index);
      loadfile(filename);
      getFilelistSelection();
      }
    }
  return 1;
}

// Copy file or directory
long FXMovieManager::onCmdFileCopy(FXObject*,FXSelector,void*){

  FXString file,rootname,imagename;
  for(FXint i=0; i<filelist->getNumItems(); i++){
    if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;

  	rootname="."+FXPath::stripExtension(file);
  	imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";

  FXString *filenamelist=getFilenames();
  if(filenamelist){
    OperationsDialog operationsdialog(this,"Copy Movie",imagename);
    FXString newname;
    for(FXint i=0; !filenamelist[i].empty(); i++){
      // operationsdialog.setOldName(filenamelist[i]);
      operationsdialog.setOldName(FXPath::absolute(FXPath::directory(filenamelist[i]),FXPath::name(filenamelist[i])));
      operationsdialog.setNewName(FXPath::absolute(FXPath::directory(filenamelist[i]),"Copy_"+FXPath::name(filenamelist[i])));
      if(!operationsdialog.execute()) break;
      newname=operationsdialog.getNewName();
      if(!FXFile::copyFiles(filenamelist[i],newname,FALSE)){
        if(FXMessageBox::error(this,MBOX_YES_NO,"Error Copying Movie","Unable to copy movie:\n\n%s  to:  %s\n\nContinue with operation?",filenamelist[i].text(),newname.text())==MBOX_CLICKED_NO) break;
        }
      }
    delete [] filenamelist;
    }
   }
  }
  return 1;
  }

// Move file or directory
long FXMovieManager::onCmdFileMove(FXObject*,FXSelector,void*){

  FXString file,rootname,imagename;
  for(FXint i=0; i<filelist->getNumItems(); i++){
    if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;

  	rootname="."+FXPath::stripExtension(file);
  	imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";

  FXString *filenamelist=getFilenames();
  if(filenamelist){
    OperationsDialog operationsdialog(this,"Move Movie",imagename);
    FXString newname;
    for(FXint i=0; !filenamelist[i].empty(); i++){
      // operationsdialog.setOldName(filenamelist[i]);
      operationsdialog.setOldName(FXPath::absolute(FXPath::directory(filenamelist[i]),FXPath::name(filenamelist[i])));
      operationsdialog.setNewName(FXPath::absolute(FXPath::directory(filenamelist[i]),FXPath::name(filenamelist[i])));
      if(!operationsdialog.execute()) break;
      newname=operationsdialog.getNewName();
      if(!FXFile::moveFiles(filenamelist[i],newname,FALSE)){
	if(FXMessageBox::error(this,MBOX_YES_NO,"Error Moving Movie","Unable to move movie:\n\n%s  to:  %s\n\nContinue with operation?",filenamelist[i].text(),newname.text())==MBOX_CLICKED_NO) break;
	}
      }
    delete [] filenamelist;
    }
   }
  }
  return 1;
  }

// Rename file or directory
long FXMovieManager::onCmdFileRename(FXObject*,FXSelector,void*){

  FXString file,rootname,imagename;
  for(FXint i=0; i<filelist->getNumItems(); i++){
    if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;

  	rootname="."+FXPath::stripExtension(file);
  	imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";

  FXString *filenamelist=getFilenames();
  if(filenamelist){
    OperationsDialog operationsdialog(this,"Rename Movie",imagename);
    FXString newname;
    for(FXint i=0; !filenamelist[i].empty(); i++){
      operationsdialog.setOldName(FXPath::name(filenamelist[i]));
      operationsdialog.setNewName(FXPath::name(filenamelist[i]));
      // operationsdialog.setNewName(FXPath::absolute(FXPath::directory(filenamelist[i]),FXPath::name(filenamelist[i])));
      if(!operationsdialog.execute()) break;
      newname=operationsdialog.getNewName();
      if(!FXFile::moveFiles(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),newname),FALSE)){
	if(FXMessageBox::error(this,MBOX_YES_NO,"Error Renaming Movie","Unable to rename movie:\n\n%s  to:  %s\n\nContinue with operation?",filenamelist[i].text(),newname.text())==MBOX_CLICKED_NO) break;
	}
      else if(!FXFile::moveFiles(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),newname),TRUE)){

        // recreate imageicon
        rootname="."+FXPath::name(FXPath::stripExtension(newname));
        createImageMovie(newname,rootname);
	system("sleep 0.5s");
        imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
	
//************************************************************************************
	// find index
	FXint search=filelist->findItem(FXPath::name(newname),-1,SEARCH_FORWARD|SEARCH_WRAP);
   	if(search!=-1){
	    printf("found name: %s %i",FXPath::name(newname).text(),search);
	    filelist->selectItem(search);
	    previewMovie(imagename,search,imgw,imgh);

	} // need a different function
//************************************************************************************

      }
    }
    delete [] filenamelist;
  }
  }
  }
  return 1;
  }

// Delete file or directory in the file list
long FXMovieManager::onCmdFileDelete(FXObject*,FXSelector,void*){
  FXuint answer=FXMessageBox::warning(this,MBOX_YES_NO,"Deleting Movie","Are you sure you want to delete these movies?");
  if(answer==MBOX_CLICKED_YES){
    FXString filetoremove,file;
    for(FXint i=0; i<filelist->getNumItems(); i++){
      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;
        filetoremove=FXPath::absolute(filelist->getDirectory(),file);
        FXTRACE((100,"filetoremove=%s\n",filetoremove.text()));
        if(!FXFile::removeFiles(filetoremove,TRUE)){
          if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Deleting Movie","Unable to delete movie: %s\nContinue with operation?",filetoremove.text())){
            break;
            }
          }
        }

      }
    }
  return 1;
  }

/****************************PROPERTIES**********************************/

// Pop up properties dialog
long FXMovieManager::onCmdProperties(FXObject*,FXSelector,void*){

  FXString info="/tmp/.fxmm/00000001.txt";
  system ("test -e /tmp/.fxmm/00000001.txt && rm /tmp/.fxmm/00000001.txt");

  FXString filename=filelist->getCurrentFile();
  createInfoMovie(filename);
  system("sleep 0.5s");

  FXchar *text;
  FXint size;

  FXFile fvideo(info,FXFile::Reading);
  size=fvideo.size();
  if(allocElms(text,size)){
    fvideo.readBlock(text,size);
    FXString block = text;

    FXRex rexvideo1("VIDEO:",0);
    FXint begv1,endv1;
    FXRex rexvideo2("kbyte",0);
    FXint begv2,endv2;
    if(rexvideo1.match(text,&begv1,&endv1)){
	if(rexvideo2.match(text,&begv2,&endv2)){
	FXint lenv=endv2-endv1+3;
    	FXString seltextv=block.mid(endv1,lenv);
    	grepvideo=seltextv;
        }
    }
    else {grepvideo="NOT FOUND";}

    FXRex rexaudio1("AUDIO:",0);
    FXint bega1,enda1;
    FXRex rexaudio2("->",0);
    FXint bega2,enda2;
    if(rexaudio1.match(text,&bega1,&enda1)){
	if(rexaudio2.match(text,&bega2,&enda2)){
	FXint lena=enda2-enda1+7;
    	FXString seltexta=block.mid(enda1,lena);
    	grepaudio=seltexta;
        }
    }
    else {grepaudio="NOT FOUND";}

  }
  fvideo.close();
  freeElms(text);

  properties->show(PLACEMENT_OWNER);

  return 1;
  }


// Update create time
long FXMovieManager::onUpdCreateTime(FXObject* sender,FXSelector,void*){
  FXString time=FXSystem::localTime(FXStat::created(filelist->getCurrentFile()));
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&time);
  return 1;
  }


// Update modified time
long FXMovieManager::onUpdModifyTime(FXObject* sender,FXSelector,void*){
  FXString time=FXSystem::localTime(FXStat::modified(filelist->getCurrentFile()));
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&time);
  return 1;
  }


// Update access time
long FXMovieManager::onUpdAccessTime(FXObject* sender,FXSelector,void*){
  FXString time=FXSystem::localTime(FXStat::accessed(filelist->getCurrentFile()));
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&time);
  return 1;
  }


// Update file location
long FXMovieManager::onUpdFileLocation(FXObject* sender,FXSelector,void*){
  FXString string=filelist->getCurrentFile();
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&string);
  return 1;
  }

// Update file size
long FXMovieManager::onUpdFileSize(FXObject* sender,FXSelector,void*){
  FXString size;
  size.fromInt(FXStat::size(filelist->getCurrentFile()));
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&size);
  return 1;
  }

// Update file type
long FXMovieManager::onUpdFileType(FXObject* sender,FXSelector,void*){
  FXString filename=filelist->getCurrentFile();
  FXFileAssoc *fileassoc=NULL;
  FXString type;
  if(FXStat::isDirectory(filename)){
    fileassoc=associations->findDirBinding(filename.text());
    type="Folder";
    }
  else if(FXStat::isExecutable(filename)){
    fileassoc=associations->findExecBinding(filename.text());
    type="Application";
    }
  else{
    fileassoc=associations->findFileBinding(filename.text());
    type="Document";
    }
  if(fileassoc) type=fileassoc->extension;
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&type);
  return 1;
  }


// Update file desc
long FXMovieManager::onUpdFileDesc(FXObject* sender,FXSelector,void*){
  FXString filename=filelist->getCurrentFile();
  FXLabel *label=(FXLabel*)sender;
  FXFileAssoc *fileassoc=NULL;
  if(FXStat::isDirectory(filename)){
    fileassoc=associations->findDirBinding(filename.text());
    }
  else if(FXStat::isExecutable(filename)){
    fileassoc=associations->findExecBinding(filename.text());
    }
  else{
    fileassoc=associations->findFileBinding(filename.text());
    }
  label->setText(FXPath::name(filename));
  if(fileassoc){
    if(fileassoc->bigicon) fileassoc->bigicon->create();
    label->setIcon(fileassoc->bigicon);
    }
  else{
    label->setIcon(NULL); // need a default suggestion here
    }
  return 1;
  }

// find video aspect
long FXMovieManager::onUpdMovieAspect(FXObject* sender,FXSelector,void*){
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&grepvideo);
  return 1;
  }

// find audio format
long FXMovieManager::onUpdAudioFormat(FXObject* sender,FXSelector,void*){
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&grepaudio);
  return 1;
  }


/****************************FILE BUTTONS**********************************/

// Play the movies from the file list
long FXMovieManager::onCmdFilePlay(FXObject*,FXSelector,void*){

   system ("test -p /tmp/.fxmm/fifo && rm /tmp/.fxmm/fifo");
   system ("test -p /tmp/.fxmm/fifo || mkfifo /tmp/.fxmm/fifo");

   FXString filetoplay,file,playlist;

    for(FXint i=0; i<filelist->getNumItems(); i++){
      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;
        filetoplay=FXPath::absolute(filelist->getDirectory(),file);
	playlist=playlist+" "+filetoplay;
      }
    }
    FXString executable = s_command + playlist + " &";
    system(executable.text());
    isrunning = TRUE;
  return 1;
  }

// Stop player
long FXMovieManager::onCmdFileStop(FXObject *,FXSelector,void *) {
	if (isrunning==TRUE){
		FILE *f;
		f=fopen("/tmp/.fxmm/fifo", "w");
		fprintf(f, "%s", "quit 1\n");
		fclose(f);
		isrunning=FALSE;
	} else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
	}
	return 1;
}

// Pause playing the movie from the file list
long FXMovieManager::onCmdFilePause(FXObject*,FXSelector,void *){
	if (isrunning==TRUE){
		FILE *f;
		f=fopen("/tmp/.fxmm/fifo", "w");
		fprintf(f, "%s", "pause\n");
		fclose(f);
	} else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
	}
	return 1;
  }

// Enable sender when items have been selected
long FXMovieManager::onUpdSelectedFile(FXObject* sender,FXSelector,void*){
    FXString file;
    FXbool isfile;

    for(FXint i=0; i<filelist->getNumItems(); i++){
       if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;
	  isfile=filelist->isItemFile(i);
	  if (isfile==FALSE){
	     return 1;
	  }
       }
    }

    sender->handle(this,getNumFilenames()?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
    return 1;
}

/***************************MOVIE PREVIEW*******************************/

// Thumbnails creation
long FXMovieManager::onCmdFilePreview(FXObject*,FXSelector,void*){
    FXString filetoplay,file,rootname,imagename,infoname;

    progressbar->setProgress(0);
    progressbar->setTotal(filelist->getNumItems());
    progressbar->setBarColor(FXRGB(0,0,250));

    for(FXint i=0; i<filelist->getNumItems(); i++){
      progressbar->increment(i);

      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;
	      
        filetoplay=FXPath::absolute(filelist->getDirectory(),file);
        rootname="."+FXPath::stripExtension(file);
        imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";

    	FXFile truefile;
	FXbool istruefile = truefile.open(imagename);
	  if(!istruefile){
	    createImageMovie(filetoplay,rootname);
	  }
      }
    }

    system("sleep 2s");

    progressbar->setProgress(0);
    progressbar->setBarColor(FXRGB(250,0,0));


    for(FXint i=0; i<filelist->getNumItems(); i++){
      progressbar->increment(i);

      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;

        rootname="."+FXPath::stripExtension(file);
        imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
	previewMovie(imagename, i, imgw, imgh);
      }
    }	
    return 1;
}


// Force tumbnails recreation 
long FXMovieManager::onCmdForceFilePreview(FXObject*,FXSelector,void*){
    FXString filetoplay,file,rootname,imagename;

    progressbar->setProgress(0);
    progressbar->setTotal(filelist->getNumItems());
    progressbar->setBarColor(FXRGB(0,0,250));

    for(FXint i=0; i<filelist->getNumItems(); i++){
      progressbar->increment(i);

      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;
	      
        filetoplay=FXPath::absolute(filelist->getDirectory(),file);
        rootname="."+FXPath::stripExtension(file);

        createImageMovie(filetoplay,rootname);

      }
   }

    system("sleep 2s");

    progressbar->setProgress(0);
    progressbar->setBarColor(FXRGB(250,0,0));


    for(FXint i=0; i<filelist->getNumItems(); i++){
      progressbar->increment(i);

      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;

        rootname="."+FXPath::stripExtension(file);
        imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
	previewMovie(imagename, i, imgw, imgh);
      }
   }
   return 1;
}


// Resize tumbnails preview 
long FXMovieManager::onCmdIncFilePreview(FXObject*,FXSelector,void*){
    FXString file,rootname,imagename;
    imgw=imgw+40;
    imgh=imgh+32;
    for(FXint i=0; i<filelist->getNumItems(); i++){

      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;

        rootname="."+FXPath::stripExtension(file);
        imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
	previewMovie(imagename, i, imgw, imgh);
      }
    }	
   return 1;
}


// Resize tumbnails preview 
long FXMovieManager::onCmdDecFilePreview(FXObject*,FXSelector,void*){
    FXString file,rootname,imagename;
    imgw=imgw-40;
    imgh=imgh-32;
    for(FXint i=0; i<filelist->getNumItems(); i++){

      if(filelist->isItemSelected(i)){
        file=filelist->getItemFilename(i);
        if(file=="..") continue;

        rootname="."+FXPath::stripExtension(file);
        imagename=FXPath::enquote(getDirectory())+"/"+rootname+"00000001/00000001.jpg";
	previewMovie(imagename, i, imgw, imgh);
      }
    }	
   return 1;
}


// clear all preview and all hidden directories
long FXMovieManager::onCmdClearPreview(FXObject*,FXSelector,void*){
    FXString dirname,executable;

    progressbar->setProgress(0);
    progressbar->setBarColor(FXRGB(0,250,0));

    for(FXint i=0; i<filelist->getNumItems(); i++){
       progressbar->increment(i);
       if(filelist->isItemDirectory(i)){
       	  dirname=filelist->getItemFilename(i);
          if(dirname=="..") continue;
	  // use of FXRex
    	  FXRex rexdir("00000001",0);
          FXint begd,endd;
          if(rexdir.match(dirname,&begd,&endd)){
             executable="cd "+FXPath::enquote(getDirectory())+"; rm -r "+dirname+" &";
             system(executable.text());
	  }
	}
     }
  return 1;
  }


FXbool FXMovieManager::createImageMovie(const FXString& filetoplay,const FXString& rootname){

	FXString command="mplayer -frames 1 -nocache -ao null -vo jpeg:subdirs="+rootname+" "+filetoplay+" &";
	FXString executable="cd "+FXPath::enquote(getDirectory())+"; "+command;
	// printf("executable: %s\n", executable.text());
        system(executable.text());
 
        return TRUE;
 }


FXbool FXMovieManager::createInfoMovie(const FXString& filename){

        FXString infoname="/tmp/.fxmm/00000001.txt";
	FXString propcommand="mplayer -frames 0 -nocache -ao null -vo null "+filename+" &> "+infoname+" &";
	// printf("propcommand: %s\n", propcommand.text());
	system(propcommand.text());

        return TRUE;
 }


// Load imagemovie to icon for preview
FXbool FXMovieManager::previewMovie(const FXString& filename, FXint i, FXint w, FXint h){
    FXString imagename=filename;
/*	
    FXIcon *oldicon=NULL;
    if(filelist->getItemBigIcon(i)){
	oldicon=filelist->getItemBigIcon(i);
	filelist->setItemBigIcon(i,NULL);
	delete oldicon;  // this delete the current icon
    }
*/

    FXIcon *tempicon=NULL;
    tempicon=new FXJPGIcon(getApp(),NULL,IMAGE_OPAQUE);

    if (tempicon){
   	FXFileStream stream;
   	if (stream.open(imagename,FXStreamLoad)){
		getApp()->beginWaitCursor();
		tempicon->loadPixels(stream);
		stream.close();

		tempicon->scale(w,h,75); 
        	tempicon->create();

		filelist->setItemBigIcon(i,tempicon);

		getApp()->endWaitCursor();
		return TRUE;
	}
    }
    return FALSE;
}


/*********************************ROUTINES**********************************/


// Get number of selected filenames, not including "." and ".."
FXint FXMovieManager::getNumFilenames() const {
  register FXint num=0;
  register FXint i;
  if(filelist->getNumItems()){
    for(i=0; i<filelist->getNumItems(); i++){
      if(filelist->isItemSelected(i) && !filelist->isItemNavigational(i)) num++;
      }
    }
  return num;
  }


// Return selected filenames, not including "." and ".."
FXString* FXMovieManager::getFilenames() const {
  register FXint num=getNumFilenames();
  register FXString *files=NULL;
  register FXint i,n;
  if(0<num){
    files=new FXString [num+1];
    for(i=n=0; i<filelist->getNumItems(); i++){
      if(filelist->isItemSelected(i) && !filelist->isItemNavigational(i)){
	files[n++]=filelist->getItemPathname(i);
	}
      }
    files[n]=FXString::null;
    }
  return files;
  }


// Get current directory
FXString FXMovieManager::getDirectory() const {
  return filelist->getDirectory();
  }



/*******************************************************************************/

// About this program
long FXMovieManager::onCmdAbout(FXObject *,FXSelector,void *) {
	FXMessageBox::information(this,MBOX_OK,"About/Copyright FxMovieManager",
	"*** FX MOVIE MANAGER ***\n"
	"a FileManager with Thumbnails, a PlayList and simple front-end to MPlayer.\n"
	"Copyright (C) 2008 Luigi Ziviani (ziviani_luigi@yahoo.it).\n\n"
	"This program is free software; you can redistribute it and/or modify\n"
	"it under the terms of the GNU General Public License as published by\n"
	"the Free Software Foundation; either version 3 of the License, or\n"
	"(at your option) any later version.\n\n"
	"This program is distributed in the hope that it will be useful,\n"
	"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
	"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
	"See the GNU General Public License for more details.\n\n"
	"You should have received a copy of the GNU General Public License\n"
	"along with this program; if not, write to the Free Software Foundation, Inc.,\n"
	"59 Temple Place, Suite 330, Boston, MA  02111-1307  USA");
	return 1;
}

// EOF
