/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright (C) 2008 Luigi Ziviani <ziviani_luigi@yahoo.it> All Rights Reserved.*
*********************************************************************************
* Id: fxmoviemanager.h,   v 1.4                    2008/01/01                   *
*********************************************************************************
* This program is free software; you can redistribute it and/or modify          *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* This program is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/
#ifndef FXMOVIEMANAGER_H
#define FXMOVIEMANAGER_H
#define FOX_17
#include <signal.h>

//! the main program class 

class PropertiesDialog;

class FXMovieManager : public FXMainWindow {
	FXDECLARE(FXMovieManager)

private:
	FXMovieManager() {}

protected:
	// declare the properties dialog class
	PropertiesDialog *properties;

	FXIcon     	*quiticon;
	FXIcon     	*fileicon;
	FXIcon     	*listicon;
	FXIcon     	*videoicon;
	FXIcon     	*audioicon;
	FXIcon     	*playicon;
	FXIcon     	*pauseicon;
	FXIcon	   	*stopicon;
	FXIcon     	*conficon;
	FXIcon	   	*upicon;
	FXIcon	   	*downicon;
	FXIcon	   	*allicon;
	FXIcon	   	*hiddenicon;
	FXIcon	   	*trashicon;
	FXIcon	   	*previdicon;
	FXIcon	   	*frevidicon;
	FXIcon	   	*incvidicon;
	FXIcon	   	*decvidicon;
	FXIcon	   	*delvidicon;


	FXIcon	   	*m_upicon;
	FXIcon	   	*m_downicon;
	FXIcon	   	*m_appendicon;
	FXIcon	   	*m_accepticon;
	FXIcon	   	*m_cancelicon;

	FXIcon	   	*m_propicon;
	FXIcon	   	*m_copyicon;
	FXIcon	   	*m_moveicon;
	FXIcon	   	*m_renameicon;
	FXIcon	   	*m_deleteicon;

	FXIcon	   	*m_refreshicon;
	FXIcon	   	*m_renamediricon;
	FXIcon	   	*m_showhiddenicon;

	FXFont 		*boldfont;

	FXMenuBar 	*menubar;           // Menu bar
	FXMenuPane 	*popupmenu;        // The Popup menu
	FXLabel 	*playlistlabel;

	FXSplitter 	*splitter1;
	FXSplitter 	*splitter2;

	FXHorizontalFrame *listframe;   // the list frame	
	FXList 		*simplelist;           // the list of movies
	FXVerticalFrame *listbuttonframe;

	FXVerticalFrame *dirframe;
	FXHorizontalFrame *filebuttonframe;
	FXVerticalFrame *fileframe;
	FXVerticalFrame *vbuttonframe;
	FXHorizontalFrame *hbuttonframe;
	FXHorizontalFrame *progressframe;

	FXDirList  	*dirlist;
	FXFileList 	*filelist;

	FXFileDict 	*associations;	// File associations

	FXComboBox 	*combobox;         // the video output choice  
	FXTextField 	*seekposition;
	FXTextField 	*endposition;

	FXProgressBar 	*progressbar;
	
	FXButton 	*quitbutton;
	FXButton 	*openbutton;
	FXButton 	*playbutton;
	FXButton 	*pausebutton;
	FXButton 	*stopbutton;

	FXButton 	*clearbutton;
	FXButton 	*freshbutton;

	FXToggleButton 	*dropbutton;
	FXToggleButton 	*audiobutton;
	FXToggleButton 	*loopbutton;
	FXToggleButton 	*zoombutton;
	FXToggleButton 	*hidebutton;

	FXString 	terminal;
	FXString 	currentdir; 
	FXString 	filename;

	FXString 	s_play;
	FXString 	s_command;
	FXString 	s_video;
	FXString 	s_full;
	FXString 	s_loop;
	FXString 	s_audio;
	FXString 	s_frame;
	FXString 	s_list;
	FXString 	s_listshow;

	FXString 	s_initial;
	FXString 	s_duration;

	FXString 	grepvideo;
	FXString 	grepaudio;

	FXint 		i_video;
	FXint 		indexnumber;            // the number of the item on the list
	FXint 		numberofitems;          // the number of items on the list
	FXint 		imgw;
	FXint 		imgh;

	FXbool 		listshow;
	FXbool 		isrunning;

protected:
	FXint getNumListnames() const;
	FXint getNumFilenames() const;
	FXString* getFilenames() const;
	FXString getDirectory() const;

	FXbool previewListMovie(const FXString& filename, FXint i);
	FXbool previewMovie(const FXString& filename, FXint i, FXint w, FXint h);
	FXbool createImageMovie(const FXString& filetoplay, const FXString& rootname);
	FXbool createInfoMovie(const FXString& filename);

	FXbool loadfile(const FXString& filename);
	FXbool readConfig();
	void getFilelistSelection();
	void getFiledialogSelection();
	void selectAll();

public:
	FXMovieManager(FXApp *);
	virtual ~FXMovieManager();
	virtual void create();

	enum{
		ID_ABOUT = FXMainWindow::ID_LAST,
		ID_FILE,
		ID_VIDEO,
		ID_AUDIO,
		ID_DROP,
		ID_FULL,
		ID_LOOP,
		ID_PLAY,
		ID_PAUSE,
		ID_STOP,
		ID_QUIT,
		ID_LIST,
		ID_MOVEUP,
		ID_MOVEDOWN,
		ID_APPEND,
		ID_INSERT,
		ID_REPLACE,
		ID_DELETE,
		ID_SELECTALL,
		ID_CLEAR,
		ID_PUTBACK,
		ID_DIRECTORYLIST,
    		ID_UPDIRECTORY,
		ID_DIRDELETE,
		ID_NEWDIR,
		ID_DIRRENAME,
		ID_FILELIST,
		ID_FILECOPY,
		ID_FILEMOVE,
		ID_FILEDELETE,
		ID_FILERENAME,
		ID_FILEPLAY,
		ID_FILEPAUSE,
		ID_FILESTOP,
		ID_FILEPREVIEW,
		ID_FORCEFILEPREVIEW,
		ID_INCFILEPREVIEW,
		ID_DECFILEPREVIEW,
		ID_CLEARPREVIEW,
    		ID_FILE_CREATED,
    		ID_FILE_ACCESSED,
    		ID_FILE_MODIFIED,
    		ID_FILE_TYPE,
    		ID_FILE_LOCATION,
    		ID_FILE_SIZE,
    		ID_FILE_DESC,
		ID_VIDEO_ASPECT,
		ID_AUDIO_FORMAT,
		ID_PROPERTIES,
		ID_LAST,
	};

public:
	// button commands
	long onCmdAbout(FXObject *,FXSelector,void *);
	long onCmdQuit(FXObject *,FXSelector,void *);
	long onCmdFile(FXObject *,FXSelector,void *);
	long onCmdVideo(FXObject *,FXSelector,void *);
	long onCmdAudio(FXObject *,FXSelector,void *);
	long onCmdPlay(FXObject *,FXSelector,void *);
	long onCmdPause(FXObject *,FXSelector,void *);
	long onCmdStop(FXObject *,FXSelector,void *);
	long onCmdDrop(FXObject *,FXSelector,void *);
	long onCmdFull(FXObject *,FXSelector,void *);
	long onCmdLoop(FXObject *,FXSelector,void *);
	// play list
	long onCmdAppend(FXObject*,FXSelector,void*);
	long onCmdInsert(FXObject*,FXSelector,void*);
	long onCmdDelete(FXObject*,FXSelector,void*);
	long onCmdReplace(FXObject*,FXSelector,void*);
	long onCmdMoveUp(FXObject*,FXSelector,void*);
	long onCmdMoveDown(FXObject*,FXSelector,void*);
	long onCmdSelectAll(FXObject*,FXSelector,void*);
	long onCmdClear(FXObject*,FXSelector,void*);
	long onListRightMouse(FXObject*,FXSelector,void* ptr);
	long onCmdPutBack(FXObject*,FXSelector,void*);
  	long onUpdSelectedList(FXObject*,FXSelector,void*);
	// directory list
  	long onCmdDirectory(FXObject*,FXSelector,void*);
  	long onCmdUpDirectory(FXObject*,FXSelector,void*);
  	long onCmdNewDir(FXObject*,FXSelector,void*);
	long onCmdDirRename(FXObject*,FXSelector,void*);
  	long onUpdNewDir(FXObject*,FXSelector,void*);
  	long onCmdDirDelete(FXObject*,FXSelector,void*);
	long onDirListPopup(FXObject*,FXSelector,void*);
	// file list
	long onFileListPopup(FXObject*,FXSelector,void*);
	long onCmdFileList(FXObject*,FXSelector,void*);
	long onCmdFileCopy(FXObject*,FXSelector,void*);
	long onCmdFileMove(FXObject*,FXSelector,void*);
	long onCmdFileRename(FXObject*,FXSelector,void*);
	long onCmdFileDelete(FXObject*,FXSelector,void*);
	long onCmdFilePlay(FXObject*,FXSelector,void*);
	long onCmdFilePause(FXObject*,FXSelector,void*);
	long onCmdFileStop(FXObject *,FXSelector,void *);
  	long onUpdSelectedFile(FXObject*,FXSelector,void*);
	long onCmdFilePreview(FXObject*,FXSelector,void*);
	long onCmdForceFilePreview(FXObject*,FXSelector,void*);
	long onCmdIncFilePreview(FXObject*,FXSelector,void*);
	long onCmdDecFilePreview(FXObject*,FXSelector,void*);
	long onCmdClearPreview(FXObject*,FXSelector,void*);
	// properties dialog
  	long onCmdProperties(FXObject*,FXSelector,void*);
  	long onUpdCreateTime(FXObject*,FXSelector,void*);
  	long onUpdModifyTime(FXObject*,FXSelector,void*);
  	long onUpdAccessTime(FXObject*,FXSelector,void*);
  	long onUpdFileType(FXObject*,FXSelector,void*);
  	long onUpdFileLocation(FXObject*,FXSelector,void*);
  	long onUpdFileSize(FXObject*,FXSelector,void*);
  	long onUpdFileDesc(FXObject*,FXSelector,void*);
  	long onUpdMovieAspect(FXObject*,FXSelector,void*);
  	long onUpdAudioFormat(FXObject*,FXSelector,void*);
};

#endif
